Flint Engine / Guide / API Reference

sample_open_spline

Function sample_open_spline 

pub fn sample_open_spline(
    points: &[SplineControlPoint],
    spacing: f32,
) -> Vec<SplineSample>
Sample an open Catmull-Rom spline at approximately spacing meters apart.

For open splines, phantom control points are created by reflecting the first and last interior segments outward.